@@ -1,5 +1,11 @@
+# coloring.
+from colorama import Fore
+import colorama
+colorama.init()
+
 # object that contains the simulation data.
 class MonteCarlo:
+    # coloring the text.
 
     '''
 
@@ -83,10 +89,10 @@ class MonteCarlo:
         self.time_seq = time_seq
         self.num_sims = num_sims
         self.ref_value_index = ref_value_index
-        print(f'Monte Carlo has been set up for {self.num_sims} simulations in a period of {self.time_seq} time measurement units.')
+        print(Fore.YELLOW + f'Monte Carlo has been set up for {self.num_sims} simulations in a period of {self.time_seq} time measurement units and executed.' + Fore.RESET)
         from vandal.hub.toolkit import random_value
-        print('Monte Carlo simulation has been executed.')
-        print('NOTE: Use data with reasonable standard deviation in order to prevent exponential growth of the function that cannot be plotted properly, recognize such abnormal values by a + sign anywhere in the data executed below.\nThe model that will be able to handle big standard deviations is currently being worked on, thank you for your patience.\n')
+        print('NOTE: Use data with reasonable standard deviation in order to prevent exponential growth of the function that cannot be plotted properly, recognize such abnormal values by a + sign anywhere in the data executed below.')
+        #print('The model that will be able to handle big standard deviations is currently being worked on, thank you for your patience.\n')
         import pandas as pd
         # this removes pandas warning of highly fragmented DataFrame for newer pandas versions.
         from warnings import simplefilter
@@ -121,7 +127,7 @@ class MonteCarlo:
 
             data[num_sim] = index_array
         print(end = '\r')
-        print('Monte Carlo simulation set up and ready to plot.')
+        print(Fore.YELLOW + 'Monte Carlo simulation set up and ready to plot.' + Fore.RESET)
         self.results = data
         return data
 
@@ -156,11 +162,11 @@ class MonteCarlo:
 
         assert (NRisk < 100), '\nTime sequence and/or number of iterations are too low for the proper risk calculation.'
 
-        print('\nRisk for this option is', round(NRisk,2), '%.')
+        print(Fore.YELLOW + '\nRisk for this option is', round(NRisk,2), '%.' + Fore.RESET)
 
     # plots the Monte Carlo simulation on a graph.
     def graph(self, graph_title = 'Monte Carlo simulation', x_title = 'X axis', y_title = 'Y axis', plot_size = (25,10), perform_block = True):
-        print('\nMonteCarlo() plotting initialized.')
+        print(Fore.GREEN + '\nMonteCarlo() plotting initialized.' + Fore.RESET)
         import matplotlib.pyplot as plt
         plt.figure(figsize = plot_size)
         plt.title('vandal (c) David Kundih, 2021.', fontsize = 14, weight = 'regular', loc = 'right')
@@ -170,7 +176,7 @@ class MonteCarlo:
         plt.xlabel(x_title, fontsize = 18, weight = 'semibold')
         plt.ylabel(y_title, fontsize = 18, weight = 'semibold')
         plt.show(block = perform_block)
-        print('MonteCarlo() plotting finished.')
+        print(Fore.GREEN + 'MonteCarlo() plotting finished.' + Fore.RESET)
 
     # shows the statistics of the Monte Carlo simulation.
     def get_stats(self, filtered = False):
@@ -191,7 +197,7 @@ class MonteCarlo:
             print('Mean value: ', mean_value)
             print('Standard deviation: ', standard_deviation)
             print('Maximum: ', maximum_value)
-            print('Minimum: ', minimum_value, '\n')
+            print('Minimum: ', minimum_value)
 
     # plots the histogram of Monte Carlo simulation.
     def hist(self, graph_title = 'Histogram of value frequencies', x_title = 'X axis', y_title = 'Y axis', plot_size = (25,10), perform_block = True, **method):
@@ -204,19 +210,19 @@ class MonteCarlo:
         std_minus3 = self.mean_value - (self.standard_deviation * 3)
 
         if self.time_seq > 50:
-            print('NOTE: Time sequence defined greatly impacts the lenght of histogram plotting.\n')
+            print(Fore.RED + 'NOTE: Time sequence defined greatly impacts the lenght of histogram plotting.\n' + Fore.RESET)
 
-        print('Histogram plotting initiated...')
+        print(Fore.YELLOW + 'Histogram plotting initiated...' + Fore.RESET)
         import matplotlib.pyplot as plt
         plt.figure(figsize = plot_size)
         plt.title('vandal (c) David Kundih, 2021.', fontsize = 14, weight = 'regular', loc = 'right')
 
         if method.get("method") != "e":
-            print('CHOSEN METHOD: Basic histogram model.')
+            print(Fore.GREEN + 'CHOSEN METHOD: Basic histogram model.' + Fore.RESET)
             plt.suptitle(graph_title, fontsize = 25, weight = 'bold')
 
         if method.get("method") == "e":
-            print('CHOSEN METHOD: Empirical rule.')
+            print(Fore.GREEN + 'CHOSEN METHOD: Empirical rule.' + Fore.RESET)
             plt.suptitle('Value division based on the Empirical rule', fontsize = 25, weight = 'bold')
             plt.axvline(x = std_plus, color = 'g', linestyle = 'dashed')
             plt.axvline(x = std_minus, color = 'r', linestyle = 'dashed')
@@ -230,20 +236,15 @@ class MonteCarlo:
         plt.xlabel(x_title, weight = 'semibold')
         plt.ylabel(y_title, weight= 'semibold')
         plt.show(block = perform_block)
-        print('Histogram plotting finished.')
+        print(Fore.YELLOW + 'Histogram plotting finished.', Fore.RESET)
 
     # access saved menu particles from function execution.  
     def get_menu(self):
         return
-
-    # access saved logs from function execution.
-    def get_logs(self):
-        return
-
+        
+    
 # CLI application.
 def MCapp():
-    import colorama
-    from colorama import Fore
     import os
     from vandal.misc._meta import __version__
     from vandal.objects import MonteCarlo
@@ -252,16 +253,14 @@ def MCapp():
         file_handler,
     )
     os.system('cls')
-    # initiates coloring.
-    colorama.init()
 
     # vandal.App version.
-    __APPversion__ = 'v 1.2.5'
+    __APPversion__ = 'v 1.2.6'
     
     # greeting.
     print(Fore.GREEN + '\n - vandal Command Line Interface Application © David Kundih -', __APPversion__)
     print(Fore.GREEN + ' - vandal package version -', 'v',__version__, Fore.RESET, '\n')
-    print(Fore.YELLOW + 'How do you wish to input your data?', Fore.RESET)
+    print(Fore.YELLOW + 'DATA INPUT OPTIONS', Fore.RESET)
     print('0 | Manual input')
     print('1 | File input\n')
     inputchoice = input('Enter the option number: ')
@@ -289,6 +288,8 @@ def MCapp():
     elif inputchoice == '1':
         inputfile = input('Enter the file destination: ')
         data = file_handler(file = inputfile)
+    else:
+            raise KeyError('Invalid input, please choose one of the stated options.')
 
     MC = MonteCarlo()
     simulations = int(input('Enter number of simulations: ') or 100)
@@ -305,9 +306,10 @@ def MCapp():
             y_axis = input('Y axis title:')
             MC.graph(graph_title = title, x_title = x_axis, y_title = y_axis)
         if action == 'change':
-            print('1 | csv')
-            print('2 | xlsx')
-            print('3 | json')
+            print(Fore.YELLOW + '\nSAVE OPTIONS', Fore.RESET)
+            print('0 | csv')
+            print('1 | xlsx')
+            print('2 | json')
             file_type = input('\nEnter the number or name of file type: ')
             output = MC.get_change()
             try:
@@ -315,9 +317,10 @@ def MCapp():
             except:
                 raise Exception('=== UNABLE TO SAVE, PLEASE SELECT ONE OF THE OPTIONS AND/OR RUN THE TERMINAL AS AN ADMINISTRATOR. ===')
         if action == 'values':
-            print('1 | csv')
-            print('2 | xlsx')
-            print('3 | json')
+            print(Fore.YELLOW + '\nSAVE OPTIONS', Fore.RESET)
+            print('0 | csv')
+            print('1 | xlsx')
+            print('2 | json')
             file_type = input('\nEnter the number or name of file type: ')
             try:
                 save_to(file = executed, prefix = 'vandal.MonteCarlo - ', func_name = 'values', choice = file_type)
@@ -331,9 +334,10 @@ def MCapp():
         if action == 'hist' or action == 'histogram':
             x_axis = input('X axis title:')
             y_axis = input('Y axis title:')
+            print(Fore.YELLOW + '\nHISTOGRAM METHODS', Fore.RESET)
             print('0 | Basic Histogram')
             print('1 | Empirical Rule Histogram')
-            method = input('\nEnter histogram method: ')
+            method = input('\nEnter the histogram method number: ')
             if method == '0':
                 MC.hist(x_title = x_axis, y_title = y_axis)
             elif method == '1':
@@ -343,7 +347,7 @@ def MCapp():
         if action == 'home':
             break
         if action == 'help':
-            print(Fore.YELLOW + 'https://github.com/dkundih/vandal', Fore.RESET)
+            print(Fore.YELLOW + '\nhttps://github.com/dkundih/vandal', Fore.RESET)
 
 if __name__ == '__main__':
     MCapp()
\ No newline at end of file
